@@ -1,4 +1,4 @@
-from __future__ import print_function
+from __future__ import annotations
 
 # python
 import abc
@@ -7,13 +7,11 @@ import logging
 import traceback
 from abc import ABCMeta,abstractmethod
 # app
-from ..exceptions import HaloError
 from .utilx import Util
 from ..const import SYSTEMChoice, LOGChoice
 from ..logs import log_json
 from ..reflect import Reflect
-from halo_app.app.request import HaloRequest, HaloCommandRequest
-from halo_app.app.response import HaloResponse
+from halo_app.app.request import AbsHaloRequest, HaloCommandRequest
 from ..classes import AbsBaseClass
 from ..settingsx import settingsx
 
@@ -21,7 +19,7 @@ settings = settingsx()
 # aws
 # other
 
-# Create your views here.
+# Create your view here.
 logger = logging.getLogger(__name__)
 
 
