@@ -1,17 +1,21 @@
 # pylint: disable=attribute-defined-outside-init
 from __future__ import annotations
 import abc
-from sqlalchemy import create_engine
-from sqlalchemy.orm import sessionmaker
-from sqlalchemy.orm.session import Session
-
-
+from typing import Dict
+from halo_app.classes import AbsBaseClass
 from halo_app.domain.repository import AbsRepository
 
 
+class AbsUnitOfWorkManager(abc.ABC):
+
+    @abc.abstractmethod
+    def start(self,usecase_id=None) -> AbsUnitOfWork:
+        pass
+
+#update one aggregate per aggregate
 class AbsUnitOfWork(abc.ABC):
 
-    items: AbsRepository = None
+    repository:AbsRepository = None
 
     def __enter__(self) -> AbsUnitOfWork:
         return self
@@ -31,8 +35,10 @@ class AbsUnitOfWork(abc.ABC):
         raise NotImplementedError
 
     def collect_new_events(self):
-        for item in self.items.seen:
+        for item in self.repository.seen:
             while item.events:
                 yield item.events.pop(0)
 
-
+    @abc.abstractmethod
+    def init_repository(self)->AbsRepository:
+        raise NotImplementedError
\ No newline at end of file
