@@ -1,4 +1,4 @@
-from __future__ import print_function
+from __future__ import annotations
 
 from enum import Enum
 
@@ -34,13 +34,18 @@ class LOGChoice(Enum):  # A subclass of Enum
     url = "url"
 
 class OPType(Enum):  # A subclass of Enum
-    event = "EVENT"
-    command = "COMMAND"
+    EVENT = "event"
+    COMMAND = "command"
+    QUERY = "query"
 
 ASYNC = "async"
+SYNC = "sync"
 
 class BusinessEventCategory(Enum):  # A subclass of Enum - if no category then implement handle method all the way
+    # execute command or event - AbsHaloCommandHandler,AbsHaloEventHandler
     EMPTY = "empty" # define a single api in code in method set_back_api
     API = "api" # define single api in config json
     SEQ = "seq" # define seq of api in config json
-    SAGA = "saga" # define saga api in config json
\ No newline at end of file
+    SAGA = "saga" # define saga api in config json
+    METHOD = "method" # define handle command/run query method
+
