@@ -1,4 +1,4 @@
-from __future__ import print_function
+from __future__ import annotations
 import abc
 import logging
 import uuid
@@ -27,7 +27,16 @@ class AbsHaloEntity(AbsHaloObject):
         else:
             self.id = id
 
+# A properly designed aggregate is one that can be modified in any way required by the business with its invariants completely consistent within a single transaction.
+# And a properly designed bounded context modifies only one aggregate instance per transaction in all cases.
 class AbsHaloAggregateRoot (AbsHaloEntity):
+    version:int = 0
     events = []
     def __init__(self,id=None):
-        super(AbsHaloAggregateRoot, self).__init__(id)
\ No newline at end of file
+        super(AbsHaloAggregateRoot, self).__init__(id)
+
+    def add_domain_event(self, *args):
+        pass
+
+    def add_error_domain_event(self, *args):
+        pass
\ No newline at end of file
