@@ -1,4 +1,4 @@
-from __future__ import print_function
+from __future__ import annotations
 
 # python
 import datetime
@@ -7,10 +7,10 @@ import uuid
 import json
 from abc import ABCMeta
 import requests
-from halo_app.providers.providers import get_provider,ProviderError
+from halo_app.infra.providers.providers import get_provider,ProviderException
 from halo_app.classes import AbsBaseClass
-from halo_app.exceptions import MaxTryHttpException, ApiError, NoApiDefinitionError, \
-    HaloMethodNotImplementedException, MissingClassConfigError, IllegalMethodException
+from halo_app.infra.exceptions import MaxTryHttpException, NoApiDefinitionException, \
+     MissingClassConfigException, IllegalMethodException, ApiException
 from halo_app.logs import log_json
 from halo_app.reflect import Reflect
 from halo_app.app.utilx import Util
@@ -81,7 +81,7 @@ class AbsBaseApi(AbsBaseClass):
                 protocol = api_config[self.name]["protocol"]
             return url,type,protocol
 
-        raise NoApiDefinitionError(self.name)
+        raise NoApiDefinitionException(self.name)
 
     def get_version(self):
         """
@@ -109,13 +109,14 @@ class AbsBaseApi(AbsBaseClass):
             if data:
                 x = str(data.decode('utf8').replace("'", '"'))
                 if x != "":
+                    #@todo fix this block
                     datax = json.loads(x)
                     datay = json.dump(datax)
                 else:
                     datay = ""
             else:
                 datay = ""
-            messageDict = {"method":method,"url":url,"views":datay,"headers":headers,"auth":auth}
+            messageDict = {"method":method,"url":url,"view":datay,"headers":headers,"auth":auth}
             print("messageDict="+str(messageDict)+" version:"+self.version)
             ret = get_provider().invoke_sync(halo_context,messageDict,service_name,version=self.version)
             print("ret:"+str(ret))
@@ -123,7 +124,7 @@ class AbsBaseApi(AbsBaseClass):
             print("content:" + str(content))
             provider_response = ProviderResponse(content["body"],ret['ResponseMetadata']["HTTPHeaders"],ret['StatusCode'])
             return provider_response
-        except ProviderError as e:
+        except ProviderException as e:
             logger.error("Unexpected Provider Error", extra=log_json(halo_context, messageDict, e))
             raise e
 
@@ -166,7 +167,7 @@ class AbsRestApi(AbsBaseApi):
                 if ret.status_code >= 500:
                     continue
                 if 200 > ret.status_code or 500 > ret.status_code >= 300:
-                    err = ApiError("error status_code " + str(ret.status_code) + " in : " + url)
+                    err = ApiException("error status_code " + str(ret.status_code) + " in : " + url)
                     err.status_code = ret.status_code
                     err.stack = None
                     raise err
@@ -288,28 +289,28 @@ class AbsRestApi(AbsBaseApi):
         except requests.ConnectionError as e:
             msg = str(e)
             logger.debug("error: " + msg, extra=log_json(self.halo_context))
-            er = ApiError(msg,e)
+            er = ApiException(msg,e)
             er.status_code = 500
             raise er
         except requests.HTTPError as e:
             msg = str(e)
             logger.debug("error: " + msg, extra=log_json(self.halo_context))
-            er = ApiError(msg,e)
+            er = ApiException(msg,e)
             er.status_code = 500
             raise er
         except requests.Timeout as e:
             msg = str(e)
             logger.debug("error: " + msg, extra=log_json(self.halo_context))
-            er = ApiError(msg,e)
+            er = ApiException(msg,e)
             er.status_code = 500
             raise er
         except requests.RequestException as e:
             msg = str(e)
             logger.debug("error: " + msg, extra=log_json(self.halo_context))
-            er = ApiError(msg,e)
+            er = ApiException(msg,e)
             er.status_code = 500
             raise er
-        except ApiError as e:
+        except ApiException as e:
             msg = str(e)
             logger.debug("error: " + msg, extra=log_json(self.halo_context))
             raise e
@@ -434,7 +435,7 @@ class AbsSoapApi(AbsBaseApi):
                                                                           LOGChoice.url.value: str(url)}))
             logger.debug("ret: " + str(soap_response), extra=log_json(self.halo_context))
             return soap_response
-        except ApiError as e:
+        except ApiException as e:
             msg = str(e)
             logger.debug("error: " + msg, extra=log_json(self.halo_context))
             raise e
@@ -448,7 +449,7 @@ class AbsSoapApi(AbsBaseApi):
             if type(soap_response) == SoapResponse:
                 return soap_response
         except AttributeError as ex:
-            raise HaloMethodNotImplementedException("function for "+str(method),ex)
+            raise ApiException("function for "+str(method),ex)
 
 """
 Request api but don't wait for response
@@ -497,12 +498,12 @@ class ApiMngr(AbsBaseClass):
                 return class_name
             #else:
 
-        raise NoApiDefinitionError(name)
+        raise NoApiDefinitionException(name)
 
     @staticmethod
-    def get_api_instance(name, *args):
+    def get_api_instance(name:str,ctx:HaloContext,method:str="", *args):
         global api_dict
-        ctx = args[0]
+        #ctx = args[0]
         id = None
         if HaloContext.items[HaloContext.CORRELATION] in ctx.keys():
             id = ctx.get(HaloContext.items[HaloContext.CORRELATION])
@@ -515,8 +516,12 @@ class ApiMngr(AbsBaseClass):
                 return api_dict[class_name+id]
             else:
                 session = requests.session()
-                params = [x for x in args]
+                params = []
+                params.append(ctx)
+                params.append(method)
                 params.append(session)
+                for x in args:
+                    params.append(x)
                 api = Reflect.instantiate(class_name, AbsBaseApi, *params)
                 lock.acquire()
                 try:
@@ -524,7 +529,7 @@ class ApiMngr(AbsBaseClass):
                 finally:
                     lock.release()
                 return api
-        raise NoApiDefinitionError(name)
+        raise NoApiDefinitionException(name)
 
 HALO_API_LIST = None
 SSM_CONFIG = None
@@ -566,7 +571,7 @@ def load_api_config(stage_type,ssm_type,func_name,API_CONFIG):
                 class_name = API_CONFIG[key]["class"]
                 api_list[key] = class_name
             else:
-                raise MissingClassConfigError(key)
+                raise MissingClassConfigException(key)
 
     HALO_API_LIST = api_list
     #ApiMngr.instance().set_api_list(api_list)
@@ -600,7 +605,7 @@ def create_api_class(name,bases,attributes=None):
         # constructor
         #"__init__": constructor,
 
-        # views members
+        # view members
         #"string_attribute": "Geeks 4 geeks !",
         #"int_attribute": 1706256,
         "name" : name,
